@@ -1,6 +1,6 @@
 /* -*-pgsql-c-*- */
 /*
- * $Header: /home/t-ishii/repository/pgpool/child.c,v 1.23 2004/05/06 06:28:41 t-ishii Exp $
+ * $Header: /home/t-ishii/repository/pgpool/child.c,v 1.24 2004/05/08 02:03:27 t-ishii Exp $
  *
  * pgpool: a language independent connection pool server for PostgreSQL 
  * written by Tatsuo Ishii
@@ -65,6 +65,11 @@ void do_child(int unix_fd, int inet_fd)
 	StartupPacket *sp;
 	POOL_CONNECTION *frontend;
 	POOL_CONNECTION_POOL *backend;
+#ifdef READ_PERFORMANCE
+	struct timeval now1, now2;
+	static long atime;
+	static int cnt;
+#endif
 
 	pool_debug("I am %d", getpid());
 	/* set up signal handlers */
@@ -112,6 +117,9 @@ void do_child(int unix_fd, int inet_fd)
 
 		/* read the startup packet */
 	retry_startup:
+#ifdef READ_PERFORMANCE
+	gettimeofday(&now1,0);
+#endif
 		sp = read_startup_packet(frontend);
 		if (sp == NULL)
 		{
@@ -120,7 +128,15 @@ void do_child(int unix_fd, int inet_fd)
 			pool_close(frontend);
 			continue;
 		}
-
+#ifdef READ_PERFORMANCE
+	gettimeofday(&now2,0);
+	atime += (now2.tv_sec - now1.tv_sec)*1000000 + (now2.tv_usec - now1.tv_usec);
+	cnt++;
+	if (cnt % 100 == 0)
+	{
+		pool_log("cnt: %d atime: %ld", cnt, atime);
+	}
+#endif
 		major = ntohl(sp->protoVersion) >> 16;
 		pool_debug("major: %d", major);
 
@@ -321,6 +337,11 @@ static POOL_CONNECTION *do_accept(int unix_fd, int inet_fd)
 	int afd;
 	int inet = 0;
 	POOL_CONNECTION *cp;
+#ifdef ACCEPT_PERFORMANCE
+	struct timeval now1, now2;
+	static long atime;
+	static int cnt;
+#endif
 
 	FD_ZERO(&readmask);
 	FD_SET(unix_fd, &readmask);
@@ -356,12 +377,25 @@ static POOL_CONNECTION *do_accept(int unix_fd, int inet_fd)
 	 * systems, we need some locking mechanism for the fd.
 	 */
 	addrlen = sizeof(addr);
+
+#ifdef ACCEPT_PERFORMANCE
+	gettimeofday(&now1,0);
+#endif
 	afd = accept(fd, &addr, &addrlen);
 	if (afd < 0)
 	{
 		pool_error("accept() failed. reason: %s", strerror(errno));
 		return NULL;
 	}
+#ifdef ACCEPT_PERFORMANCE
+	gettimeofday(&now2,0);
+	atime += (now2.tv_sec - now1.tv_sec)*1000000 + (now2.tv_usec - now1.tv_usec);
+	cnt++;
+	if (cnt % 100 == 0)
+	{
+		pool_log("cnt: %d atime: %ld", cnt, atime);
+	}
+#endif
 	pool_debug("I am %d accept fd %d", getpid(), afd);
 
 	/* set NODELAY and KEEPALIVE options if INET connection */
