@@ -1,6 +1,6 @@
 /* -*-pgsql-c-*- */
 /*
- * $Header: /home/t-ishii/repository/pgpool/pool_process_query.c,v 1.14 2004/05/06 06:37:55 t-ishii Exp $
+ * $Header: /home/t-ishii/repository/pgpool/pool_process_query.c,v 1.15 2004/05/07 13:57:52 t-ishii Exp $
  *
  * pgpool: a language independent connection pool server for PostgreSQL 
  * written by Tatsuo Ishii
@@ -549,7 +549,7 @@ static POOL_STATUS AsciiRow(POOL_CONNECTION *frontend,
 
 	/* NULL map */
 	pool_read(MASTER(backend), nullmap, nbytes);
-	if (pool_write_and_flush(frontend, nullmap, nbytes) < 0)
+	if (pool_write(frontend, nullmap, nbytes) < 0)
 	{
 		return POOL_END;
 	}
@@ -665,7 +665,8 @@ static POOL_STATUS BinaryRow(POOL_CONNECTION *frontend,
 	pool_read(MASTER(backend), nullmap, nbytes);
 	if (REPLICATION)
 		pool_read(SECONDARY(backend), nullmap, nbytes);
-	if (pool_write_and_flush(frontend, nullmap, nbytes) < 0)
+
+	if (pool_write(frontend, nullmap, nbytes) < 0)
 	{
 		return POOL_END;
 	}
